/**
 * Utility functions for applying transformations to images.
 * 
 * @author Keith Schwarz (htiek@cs.stanford.edu)
 */

import acm.graphics.*;

public class HistogramEqualizationImageTransforms {
	/**
	 * Given a GImage, returns a new GImage that's a grayscale representation of the
	 * original image.
	 * 
	 * @param image The image to transform.
	 * @return The result.
	 */
	public static GImage toGrayscale(GImage image) {
		int[][] pixels = image.getPixelArray();
		
		for (int row = 0; row < pixels.length; row++) {
			for (int col = 0; col < pixels[row].length; col++) {
				/* Use the standard formula for grayscale conversion. */
				int intensity = (int)(0.3 * GImage.getRed(pixels[row][col]) +
					                  0.59 * GImage.getGreen(pixels[row][col]) +
					                  0.11 * GImage.getBlue(pixels[row][col]) + 0.5);
				pixels[row][col] = GImage.createRGBPixel(intensity, intensity, intensity);
			}
		}
		
		return new GImage(pixels);
	}

	/**
	 * Given an array of pixels, returns an array of the luminances of those pixels.
	 * 
	 * @param pixels The input image.
	 * @return The image luminances.
	 */
	public static int[][] imageToLuminances(int[][] pixels) {
		int[][] luminances = new int[pixels.length][pixels[0].length];
	
		/* Obtain the intensity by looking at the red component.  Any of the components
		 * would work here.
		 */
		for (int row = 0; row < pixels.length; row++) {
			for (int col = 0; col < pixels[row].length; col++) {
				luminances[row][col] = GImage.getRed(pixels[row][col]);
			}
		}
		
		return luminances;
	}
}
